# Geodata 
Geodata provides a placename lookup gazeteer utilizing a local database using the 20M entry geonames.org data.   

<a name="features"></a>
## Features  
* Builds a local sqlite3 database of geoname.org data.   
* Provides powerful search routines   
* Word search   
* Wildcard search   
* Phonetic search using Double Metaphone  
* Search by feature type.  E.g. all mountains starting with Be in Germany
   
[See User Guide Wiki for details](https://github.com/corb555/Geodata/wiki/User-Guide)
